export interface IState {
    clone(): IState;
    equals(other: IState): boolean;
}
export interface CommentRule {
    lineComment?: string;
    blockComment?: CharacterPair;
}
export interface IndentationRule {
    decreaseIndentPattern: RegExp;
    increaseIndentPattern: RegExp;
    indentNextLinePattern?: RegExp;
    unIndentedLinePattern?: RegExp;
}
export declare type CharacterPair = [string, string];
export declare enum IndentAction {
    None = 0,
    Indent = 1,
    IndentOutdent = 2,
    Outdent = 3,
}
export interface EnterAction {
    indentAction: IndentAction;
    outdentCurrentLine?: boolean;
    appendText?: string;
    removeText?: number;
}
export interface OnEnterRule {
    beforeText: RegExp;
    afterText?: RegExp;
    action: EnterAction;
}
export interface IAutoClosingPair {
    open: string;
    close: string;
}
export interface IAutoClosingPairConditional extends IAutoClosingPair {
    notIn?: string[];
}
export interface IBracketElectricCharacterContribution {
    docComment?: IDocComment;
}
export interface IDocComment {
    open: string;
    close: string;
}
export interface IToken {
    startIndex: number;
    scopes: string;
}
export interface ILineTokens {
    tokens: IToken[];
    endState: IState;
}
export interface LanguageConfiguration {
    comments?: CommentRule;
    brackets?: CharacterPair[];
    wordPattern?: RegExp;
    indentationRules?: IndentationRule;
    onEnterRules?: OnEnterRule[];
    autoClosingPairs?: IAutoClosingPairConditional[];
    surroundingPairs?: IAutoClosingPair[];
    __electricCharacterSupport?: IBracketElectricCharacterContribution;
}
export interface TokensProvider {
    getInitialState(): IState;
    tokenize(line: string, state: IState): ILineTokens;
}
export interface IState {
    clone(): IState;
    equals(other: IState): boolean;
}
export interface ILineTokens {
    tokens: IToken[];
    endState: IState;
}
